@@ -11,7 +11,7 @@ const Me = ExtensionUtils.getCurrentExtension();
 const { WindowPicker, WindowPickerToggle } = Me.imports.windowPicker;
 const { WorkspaceIndicator } = Me.imports.workspaceIndicator;
 
-const Gettext = imports.gettext.domain('gnome-shell-extensions');
+const Gettext = imports.gettext.domain(Me.metadata['gettext-domain']);
 const _ = Gettext.gettext;
 
 const ICON_TEXTURE_SIZE = 24;
@@ -612,7 +612,6 @@ class AppButton extends BaseButton {
             this._contextMenuManager.addMenu(this._appContextMenu);
             this.label_actor = this._multiWindowTitle.label_actor;
         }
-
     }
 
     _onClicked(actor, button) {
@@ -745,21 +744,20 @@ class WindowList extends St.Widget {
         this._appStateChangedId = this._appSystem.connect(
             'app-state-changed', this._onAppStateChanged.bind(this));
 
-        this._keyboardVisiblechangedId = Main.layoutManager.connect(
-            'keyboard-visible-changed',
-            (o, state) => {
-                Main.layoutManager.keyboardBox.visible = state;
-                let { keyboardBox } = Main.layoutManager;
-                keyboardBox.visible = state;
-                if (state) {
-                    Main.uiGroup.set_child_above_sibling(
-                        this, keyboardBox);
-                } else {
-                    Main.uiGroup.set_child_above_sibling(
-                        this, Main.layoutManager.panelBox);
-                }
-                this._updateKeyboardAnchor();
-            });
+        // Hack: OSK gesture is tied to visibility, piggy-back on that
+        this._keyboardVisiblechangedId =
+            Main.keyboard._bottomDragAction.connect('notify::enabled',
+                action => {
+                    const visible = !action.enabled;
+                    if (visible) {
+                        Main.uiGroup.set_child_above_sibling(
+                            this, Main.layoutManager.keyboardBox);
+                    } else {
+                        Main.uiGroup.set_child_above_sibling(
+                            this, Main.layoutManager.panelBox);
+                    }
+                    this._updateKeyboardAnchor();
+                });
 
         let workspaceManager = global.workspace_manager;
 
@@ -920,11 +918,8 @@ class WindowList extends St.Widget {
     }
 
     _updateKeyboardAnchor() {
-        if (!Main.keyboard.keyboardActor)
-            return;
-
-        let translationY = Main.overview.visible ? 0 : this.height;
-        Main.keyboard.keyboardActor.translation_y = -translationY;
+        const translationY = Main.overview.visible ? 0 : this.height;
+        Main.layoutManager.keyboardBox.translation_y = -translationY;
     }
 
     _onAppStateChanged(appSys, app) {
@@ -1077,11 +1072,9 @@ class WindowList extends St.Widget {
         this._appSystem.disconnect(this._appStateChangedId);
         this._appStateChangedId = 0;
 
-        Main.layoutManager.disconnect(this._keyboardVisiblechangedId);
+        Main.keyboard._bottomDragAction.disconnect(this._keyboardVisiblechangedId);
         this._keyboardVisiblechangedId = 0;
 
-        Main.layoutManager.hideKeyboard();
-
         this._disconnectWorkspaceSignals();
         global.workspace_manager.disconnect(this._nWorkspacesChangedId);
         this._nWorkspacesChangedId = 0;
@@ -1109,6 +1102,8 @@ class WindowList extends St.Widget {
 
 class Extension {
     constructor() {
+        ExtensionUtils.initTranslations();
+
         this._windowLists = null;
         this._hideOverviewOrig = Main.overview.hide;
     }
